all_languages = ["da", "de", "el", "en", "es", "fr", "it", "nl", "no", "pl", "pt", "ro", "zh-CN"]

all_languages_with_latin_characters = ["da", "de", "en", "es", "fr", "it", "nl", "no", "pl", "pt", "ro"]
